.. _atomic-data-download:

**********************
Atomic Data for TARDIS
**********************

For a detailed description of the datasets go to :doc:`atomic_data_description`

.. include:: current_public_table.rst


